==> django_celery_boost-0.2.0.tar.gz: django_celery_boost-0.2.0/README.md <==
# django-celery-boost

[![Test](https://github.com/unicef/django-celery-boost/actions/workflows/test.yml/badge.svg)](https://github.com/unicef/django-celery-boost/actions/workflows/test.yml)
[![Lint](https://github.com/unicef/django-celery-boost/actions/workflows/lint.yml/badge.svg)](https://github.com/unicef/django-celery-boost/actions/workflows/lint.yml)
[![Documentation](https://github.com/unicef/django-celery-boost/actions/workflows/docs.yml/badge.svg)](https://unicef.github.io/django-celery-boost/)
[![codecov](https://codecov.io/github/unicef/django-celery-boost/graph/badge.svg?token=L7HA5PJ45B)](https://codecov.io/github/unicef/django-celery-boost)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/django-celery-boost)](https://pypi.org/project/django-celery-boost/)


django-celery-boost is a small Django Abstract Model that provides some useful methods to manage 
Models that represents the "context" of a Celery task.  

## Links

- Documentation https://unicef.github.io/django-celery-boost/
- Source Code - https://github.com/unicef/django-celery-boost
- Pypi - https://pypi.org/project/django-celery-boost/




## Features

- Easy control Django Model records to celery task
- Business View of Celery Task 
- Revoke tasks with to running workers
- Retrieve task position in the queue
- Admin integration to inspect task status (running/result/error)



---

Django-celery-boost has been developed as part of the UNICEF HOPE project, read more at https://unicef.github.io/hope-documentation/

---

==> django_celery_boost-0.4.1.tar.gz: django_celery_boost-0.4.1/README.md <==
# django-celery-boost

[![Test](https://github.com/unicef/django-celery-boost/actions/workflows/test.yml/badge.svg)](https://github.com/unicef/django-celery-boost/actions/workflows/test.yml)
[![Lint](https://github.com/unicef/django-celery-boost/actions/workflows/lint.yml/badge.svg)](https://github.com/unicef/django-celery-boost/actions/workflows/lint.yml)
[![Documentation](https://github.com/unicef/django-celery-boost/actions/workflows/docs.yml/badge.svg)](https://unicef.github.io/django-celery-boost/)
[![codecov](https://codecov.io/github/unicef/django-celery-boost/graph/badge.svg?token=L7HA5PJ45B)](https://codecov.io/github/unicef/django-celery-boost)
[![PyPI - Python Version](https://img.shields.io/pypi/v/django-celery-boost)](https://pypi.org/project/django-celery-boost/)



django-celery-boost is a small Django Abstract Model that provides some useful methods to manage 
Models that represents the "context" of a Celery task.  

## Links

- Documentation https://unicef.github.io/django-celery-boost/
- Source Code - https://github.com/unicef/django-celery-boost
- Pypi - https://pypi.org/project/django-celery-boost/




## Features

- Easy control Django Model records to celery task
- Business View of Celery Task 
- Revoke tasks with to running workers
- Retrieve task position in the queue
- Admin integration to inspect task status (running/result/error)



---

Django-celery-boost has been developed as part of the UNICEF HOPE project, read more at https://unicef.github.io/hope-documentation/

---
